@@ -12,14 +12,24 @@ is handled by the system_blocker module.
 import logging
 import re
 from pathlib import Path
-from typing import Any, Dict, Protocol, runtime_checkable
+from typing import Any, Dict, Protocol, runtime_checkable, Union
+
+import emoji
+
+from .filesystem_sandbox import initialize_sandbox, get_sandbox
+from .patterns import (
+    DEFAULT_DANGEROUS_URL_PATTERNS,
+    DEFAULT_DANGEROUS_SCRIPT_PATTERNS,
+    DEFAULT_DANGEROUS_COMMAND_PATTERNS,
+    DEFAULT_DANGEROUS_ARGUMENT_NAMES,
+)
 
 
 @runtime_checkable
 class SafetyProvider(Protocol):
     """Protocol for pluggable safety providers."""
 
-    def set_fs_root(self, root: str | Path) -> None: ...
+    def set_fs_root(self, root: Union[str, Path]) -> None: ...
     def sanitize_tool_arguments(
         self, tool_name: str, arguments: Dict[str, Any]
     ) -> Dict[str, Any]: ...
@@ -35,63 +45,56 @@ class SafetyProvider(Protocol):
 class SafetyFilter(SafetyProvider):
     """Filters and suppresses dangerous operations during fuzzing."""
 
-    def __init__(self):
-        self.dangerous_url_patterns = [
-            r"https?://",  # Any HTTP/HTTPS URL - CRITICAL to block
-            r"ftp://",  # FTP URLs
-            r"file://",  # File URLs
-            r"www\.",  # Common web URLs
-            r"[a-zA-Z0-9-]+\.(com|org|net|edu|gov|mil|int|co\.uk|de|fr|jp|cn)",
-        ]
-
-        self.dangerous_command_patterns = [
-            # Browser/app launching commands
-            r"xdg-open",  # Linux open command
-            r"open\s+",  # macOS open command
-            r"start\s+",  # Windows start command
-            r"cmd\s+/c\s+start",  # Windows cmd start
-            r"explorer\.exe",  # Windows explorer
-            r"rundll32",  # Windows rundll32
-            # Browser executables
-            r"(firefox|chrome|chromium|safari|edge|opera|brave)\.exe",
-            r"(firefox|chrome|chromium|safari|edge|opera|brave)$",
-            # System executables that could launch apps
-            r"\.exe\s*$",
-            r"\.app/Contents/MacOS/",
-            r"\.app\s*$",
-            r"\.dmg\s*$",
-            r"\.msi\s*$",
-            # System modification commands
-            r"sudo\s+",
-            r"rm\s+-rf",
-            r"format\s+",
-            r"del\s+/[sq]",
-            r"shutdown",
-            r"reboot",
-            r"halt",
-        ]
-
-        self.dangerous_argument_names = [
-            "url",
-            "link",
-            "uri",
-            "href",
-            "website",
-            "webpage",
-            "browser",
-            "application",
-            "app",
-            "executable",
-            "exec",
-            "path",
-            "file_path",
-            "filepath",
-            "command",
-            "cmd",
-        ]
+    def __init__(
+        self,
+        dangerous_url_patterns: list[str] | None = None,
+        dangerous_script_patterns: list[str] | None = None,
+        dangerous_command_patterns: list[str] | None = None,
+        dangerous_argument_names: list[str] | None = None,
+    ):
+        # Allow dependency injection of patterns for easier testing and configurability
+        self.dangerous_url_patterns = self._compile_patterns(
+            dangerous_url_patterns or DEFAULT_DANGEROUS_URL_PATTERNS
+        )
+        self.dangerous_script_patterns = self._compile_patterns(
+            dangerous_script_patterns or DEFAULT_DANGEROUS_SCRIPT_PATTERNS
+        )
+        self.dangerous_command_patterns = self._compile_patterns(
+            dangerous_command_patterns or DEFAULT_DANGEROUS_COMMAND_PATTERNS
+        )
+        # Normalize argument names for case-insensitive membership checks
+        self.dangerous_argument_names = {
+            n.lower()
+            for n in (dangerous_argument_names or DEFAULT_DANGEROUS_ARGUMENT_NAMES)
+        }
 
         # Track blocked operations for testing and analysis
         self.blocked_operations = []
+        self._fs_root: Union[Path, None] = None
+
+    def set_fs_root(self, root: str | Path) -> None:
+        """Initialize filesystem sandbox with the specified root directory."""
+        try:
+            sandbox = initialize_sandbox(str(root))
+            logging.info(
+                f"Filesystem sandbox initialized at: {sandbox.get_sandbox_root()}"
+            )
+        except Exception as e:
+            logging.error(
+                f"Failed to initialize filesystem sandbox with root '{root}': {e}"
+            )
+            # Initialize with default sandbox
+            initialize_sandbox()
+
+    def _compile_patterns(self, patterns):
+        """Compile string patterns into regex Pattern objects."""
+        compiled = []
+        for p in patterns:
+            if isinstance(p, re.Pattern):
+                compiled.append(p)
+            else:
+                compiled.append(re.compile(p, re.IGNORECASE))
+        return compiled
 
     def contains_dangerous_url(self, value: str) -> bool:
         """Check if a string contains a dangerous URL."""
@@ -99,7 +102,17 @@ class SafetyFilter(SafetyProvider):
             return False
 
         for pattern in self.dangerous_url_patterns:
-            if re.search(pattern, value, re.IGNORECASE):
+            if pattern.search(value):
+                return True
+        return False
+
+    def contains_dangerous_script(self, value: str) -> bool:
+        """Check if a string contains dangerous script injection patterns."""
+        if not value:
+            return False
+
+        for pattern in self.dangerous_script_patterns:
+            if pattern.search(value):
                 return True
         return False
 
@@ -109,18 +122,92 @@ class SafetyFilter(SafetyProvider):
             return False
 
         for pattern in self.dangerous_command_patterns:
-            if re.search(pattern, value, re.IGNORECASE):
+            if pattern.search(value):
                 return True
         return False
 
     def sanitize_tool_arguments(
         self, tool_name: str, arguments: Dict[str, Any]
     ) -> Dict[str, Any]:
-        """Sanitize tool arguments to remove dangerous content recursively."""
+        """Sanitize tool arguments to remove dangerous content and enforce 
+        filesystem sandbox."""
         if not arguments:
             return arguments
 
-        return self._sanitize_value("root", arguments)
+        # First sanitize for dangerous content
+        sanitized_args = self._sanitize_value("root", arguments)
+        
+        # Then sanitize filesystem paths if sandbox is enabled
+        sandbox = get_sandbox()
+        if sandbox:
+            sanitized_args = self._sanitize_filesystem_paths(sanitized_args, tool_name)
+            
+        return sanitized_args
+
+    def _sanitize_filesystem_paths(
+        self, arguments: Dict[str, Any], tool_name: str
+    ) -> Dict[str, Any]:
+        """Sanitize filesystem paths to ensure they're within the sandbox."""
+        sandbox = get_sandbox()
+        if not sandbox:
+            return arguments
+            
+        # Common filesystem-related argument names
+        filesystem_args = {
+            'path', 'file', 'filename', 'filepath', 'directory', 'dir', 'folder',
+            'source', 'destination', 'dest', 'target', 'output', 'input',
+            'root', 'base', 'location', 'where', 'to', 'from'
+        }
+        
+        sanitized = {}
+        for key, value in arguments.items():
+            if isinstance(value, (str, Path)):
+                value_str = str(value)
+                looks_like_path = (
+                    key.lower() in filesystem_args
+                    or "/" in value_str
+                    or "\\" in value_str
+                    or value_str.endswith(('.txt', '.json', '.yaml', '.yml', '.log', 
+                                           '.md', '.py', '.js', '.html', '.css', 
+                                           '.xml', '.csv'))
+                )
+                if looks_like_path:
+                    if sandbox.is_path_safe(value_str):
+                        sanitized[key] = value_str
+                    else:
+                        safe_path = sandbox.sanitize_path(value_str)
+                        logging.info(
+                            "Sanitized filesystem path '%s': '%s' -> '%s'",
+                            key,
+                            value_str,
+                            safe_path,
+                        )
+                        sanitized[key] = safe_path
+                else:
+                    sanitized[key] = value
+            elif isinstance(value, dict):
+                sanitized[key] = self._sanitize_filesystem_paths(value, tool_name)
+            elif isinstance(value, list):
+                new_list = []
+                for item in value:
+                    if isinstance(item, dict):
+                        new_list.append(
+                            self._sanitize_filesystem_paths(item, tool_name)
+                        )
+                    elif isinstance(item, (str, Path)):
+                        item_key = f"{key}_item"
+                        new_list.append(
+                            self._sanitize_filesystem_paths(
+                                {item_key: item}, tool_name
+                            )[item_key]
+                        )
+                    else:
+                        new_list.append(item)
+                sanitized[key] = new_list
+            else:
+                sanitized[key] = value
+                
+        return sanitized
 
     def _sanitize_value(self, key: str, value: Any) -> Any:
         """Recursively sanitize any value (string, dict, list, etc.)."""
@@ -152,6 +239,11 @@ class SafetyFilter(SafetyProvider):
             logging.warning(f"BLOCKED dangerous URL in {arg_name}: {value[:50]}...")
             return "[BLOCKED_URL]"
 
+        # CRITICAL: Check for script injection - completely block them
+        if self.contains_dangerous_script(value):
+            logging.warning(f"BLOCKED dangerous script in {arg_name}: {value[:50]}...")
+            return "[BLOCKED_SCRIPT]"
+
         # CRITICAL: Check for dangerous commands - completely block them
         if self.contains_dangerous_command(value):
             logging.warning(f"BLOCKED dangerous command in {arg_name}: {value[:50]}...")
@@ -295,7 +387,9 @@ class SafetyFilter(SafetyProvider):
             logging.warning(f"Arguments: {safe_args}")
 
             if dangerous_content:
-                logging.warning("🚨 DANGEROUS CONTENT DETECTED:")
+                logging.warning(
+                    f"{emoji.emojize(':police_car_light:')} DANGEROUS CONTENT DETECTED:"
+                )
                 for content in dangerous_content:
                     logging.warning(f"  • {content}")
 
@@ -359,95 +453,6 @@ class SafetyFilter(SafetyProvider):
 
         return summary
 
-    def print_blocked_operations_summary(self):
-        """Print a formatted summary of all blocked operations."""
-        summary = self.get_blocked_operations_summary()
-
-        if summary["total_blocked"] == 0:
-            logging.info("\U00002705 No operations were blocked by safety system")
-            return
-
-        logging.info("=" * 80)
-        logging.info("\U0001f6e1 SAFETY SYSTEM BLOCKED OPERATIONS SUMMARY")
-        logging.info("=" * 80)
-        logging.info(f"Total Operations Blocked: {summary['total_blocked']}")
-
-        if summary["tools_blocked"]:
-            logging.info("\nTools Blocked:")
-            for tool, count in summary["tools_blocked"].items():
-                logging.info(f"  • {tool}: {count} times")
-
-        if summary["reasons"]:
-            logging.info("\nBlocking Reasons:")
-            for reason, count in summary["reasons"].items():
-                logging.info(f"  • {reason}: {count} times")
-
-        if summary["dangerous_content_types"]:
-            logging.info("\nDangerous Content Types:")
-            for content_type, count in summary["dangerous_content_types"].items():
-                logging.info(f"  • {content_type}: {count} instances")
-
-        logging.info("=" * 80)
-
-    def export_safety_data(self, filename: str = None) -> str:
-        """Export safety data to JSON file for analysis."""
-        import json
-        from datetime import datetime
-
-        if not filename:
-            timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
-            filename = f"safety_report_{timestamp}.json"
-
-        safety_data = {
-            "export_timestamp": datetime.now().isoformat(),
-            "summary": self.get_blocked_operations_summary(),
-            "detailed_operations": self.blocked_operations,
-            "safety_config": {
-                "dangerous_url_patterns": self.dangerous_url_patterns,
-                "dangerous_command_patterns": self.dangerous_command_patterns,
-                "dangerous_argument_names": self.dangerous_argument_names,
-            },
-        }
-
-        try:
-            with open(filename, "w") as f:
-                json.dump(safety_data, f, indent=2, default=str)
-
-            logging.info(f"Safety data exported to: {filename}")
-            return filename
-        except Exception as e:
-            logging.error(f"Failed to export safety data: {e}")
-            return ""
-
-    def get_safety_statistics(self) -> Dict[str, Any]:
-        """Get comprehensive safety statistics for reporting."""
-        summary = self.get_blocked_operations_summary()
-
-        # Calculate additional statistics
-        stats = {
-            "total_operations_blocked": summary["total_blocked"],
-            "unique_tools_blocked": len(summary["tools_blocked"]),
-            "blocking_reasons": summary["reasons"],
-            "dangerous_content_breakdown": summary["dangerous_content_types"],
-            "most_blocked_tool": None,
-            "most_blocked_tool_count": 0,
-            "risk_assessment": "low",
-        }
-
-        # Find most blocked tool
-        if summary["tools_blocked"]:
-            most_blocked = max(summary["tools_blocked"].items(), key=lambda x: x[1])
-            stats["most_blocked_tool"] = most_blocked[0]
-            stats["most_blocked_tool_count"] = most_blocked[1]
-
-        # Assess overall risk
-        if stats["total_operations_blocked"] > 10:
-            stats["risk_assessment"] = "high"
-        elif stats["total_operations_blocked"] > 5:
-            stats["risk_assessment"] = "medium"
-
-        return stats
-
 
 _current_safety: SafetyProvider = SafetyFilter()
 
@@ -468,7 +473,7 @@ def load_safety_plugin(dotted_path: str) -> None:
     import importlib
 
     module = importlib.import_module(dotted_path)
-    provider: SafetyProvider | None = None
+    provider: Union[SafetyProvider, None] = None
     if hasattr(module, "get_safety"):
         provider = getattr(module, "get_safety")()
     elif hasattr(module, "safety"):
@@ -484,7 +489,7 @@ def disable_safety() -> None:
     """Disable safety by installing a no-op provider."""
 
     class _NoopSafety(SafetyProvider):
-        def set_fs_root(self, root: str | Path) -> None:  # noqa: ARG002
+        def set_fs_root(self, root: Union[str, Path]) -> None:  # noqa: ARG002
             return
 
         def sanitize_tool_arguments(
